import { Entity, PrimaryGeneratedColumn, Column } from "typeorm";
import {
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsPositive,
} from "class-validator";

/**
 * Defines the scan interface.
*/
export abstract class IScan {
  /**
   * Autogenerated unique id (primary key).
   */
  @PrimaryGeneratedColumn()
  @IsOptional()
  @IsInt()
  id: number;

  /**
   * The associated runner.
   */
  @Column()
  @IsNotEmpty()
  runner: Runner;

  /**
   * The scan's distance in meters.
   */
  @Column()
  @IsInt()
  @IsPositive()
  distance: number;
}
